addresses.Addresses (Addresses) — amici1

# `addresses.Addresses` (Addresses)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: country>`

- `<django.db.models.fields.related.ForeignKey: city>`

- `<django.db.models.fields.CharField: zip_code>`

- `<django.db.models.fields.related.ForeignKey: region>`

- `<django.db.models.fields.CharField: addr1>`

- `<django.db.models.fields.CharField: street_prefix>`

- `<django.db.models.fields.CharField: street>`

- `<django.db.models.fields.CharField: street_no>`

- `<django.db.models.fields.CharField: street_box>`

- `<django.db.models.fields.CharField: addr2>`

- `<lino.core.choicelists.ChoiceListField: data_source>`

- `<lino.core.choicelists.ChoiceListField: address_type>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.fields.CharField: remark>`

- `<django.db.models.fields.BooleanField: primary>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino_xl.lib.addresses.models.Addresses>`

- Address line before street (addr1) : Address line before street

- `<Panel main_3 in lino.core.layouts.DetailLayout on lino_xl.lib.addresses.models.Addresses>`

- Address line after street (addr2) : Address line to print below street line.

- `<Panel main_5 in lino.core.layouts.DetailLayout on lino_xl.lib.addresses.models.Addresses>`

- `<Panel main_6 in lino.core.layouts.DetailLayout on lino_xl.lib.addresses.models.Addresses>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Labels (print_labels) : Add this action to your table, which is expected to execute on a model which implements Addressable.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Address.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<django.db.models.fields.related.ForeignKey: place>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.choicelists.ChoiceListField: address_type>`

## Filter parameters